#!/usr/bin/env bash

# Copyright (C) Viktor Szakats. See LICENSE.md
# SPDX-License-Identifier: MIT

# shellcheck disable=SC3040,SC2039
set -o xtrace -o errexit -o nounset; [ -n "${BASH:-}${ZSH_NAME:-}" ] && set -o pipefail

export _NAM _VER _OUT _BAS _DST

_NAM="$(basename "$0" | cut -f 1 -d '.')"
_VER="$1"

(
  cd "${_NAM}" || exit 0

  rm -r -f "${_PKGDIR:?}" "${_BLDDIR:?}"

  CPPFLAGS='-DZSTD_TRACE=0'  # disable public debug functions with always-visible weak symbols

  if [ "${_OS}" != 'win' ]; then
    CPPFLAGS+=' -DZSTDLIB_VISIBLE='
    CPPFLAGS+=' -DZSTDERRORLIB_VISIBLE='
  fi

  # shellcheck disable=SC2086
  cmake build/cmake -B "${_BLDDIR}" ${_CMAKE_GLOBAL} ${_CMAKE_CXX_GLOBAL} \
    '-DZSTD_BUILD_CONTRIB=OFF' \
    '-DZSTD_BUILD_TESTS=OFF' \
    '-DZSTD_LEGACY_SUPPORT=OFF' \
    '-DZSTD_BUILD_PROGRAMS=OFF' \
    '-DZSTD_PROGRAMS_LINK_SHARED=OFF' \
    '-DZSTD_BUILD_SHARED=OFF' \
    '-DZSTD_BUILD_STATIC=ON' \
    '-DZSTD_MULTITHREAD_SUPPORT=ON' \
    "-DCMAKE_C_FLAGS=${_CFLAGS_GLOBAL_CMAKE} ${_CFLAGS_GLOBAL} ${_CPPFLAGS_GLOBAL} ${CPPFLAGS} ${_LDFLAGS_GLOBAL}" \
    "-DCMAKE_CXX_FLAGS=${_CFLAGS_GLOBAL_CMAKE} ${_CFLAGS_GLOBAL} ${_CPPFLAGS_GLOBAL} ${CPPFLAGS} ${_LDFLAGS_GLOBAL} ${_CXXFLAGS_GLOBAL} ${_LDFLAGS_CXX_GLOBAL}"

  make --directory="${_BLDDIR}" --jobs="${_JOBS}" install "DESTDIR=$(pwd)/${_PKGDIR}"

  # Delete .pc files
  rm -r -f "${_PP}"/lib/pkgconfig

  # Make steps for determinism

  readonly _ref='CHANGELOG'

  # shellcheck disable=SC2086
  "${_STRIP_LIB}" ${_STRIPFLAGS_LIB} "${_PP}"/lib/*.a

  touch -c -r "${_ref}" "${_PP}"/include/*.h
  touch -c -r "${_ref}" "${_PP}"/lib/*.a

  # Create package

  _OUT="${_NAM}-${_VER}${_REVSUFFIX}${_PKGSUFFIX}"
  _BAS="${_NAM}-${_VER}${_PKGSUFFIX}"
  _DST="$(pwd)/_pkg"; rm -r -f "${_DST}"

  mkdir -p "${_DST}/include"
  mkdir -p "${_DST}/lib"

  cp -f -p "${_PP}"/include/*.h "${_DST}/include/"
  cp -f -p "${_PP}"/lib/*.a     "${_DST}/lib/"
  cp -f -p CHANGELOG            "${_DST}/CHANGELOG.txt"
  cp -f -p README.md            "${_DST}/"
  cp -f -p LICENSE              "${_DST}/LICENSE.txt"

  ../_pkg.sh "$(pwd)/${_ref}"
)
